#
# Copyright Michael Orlitzky
#
# http://michael.orlitzky.com/
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# http://www.fsf.org/licensing/licenses/gpl.html
#

require 'test/unit'
require 'src/websites/yikers'

class YikersTest < Test::Unit::TestCase

  def test_owns_yikers_urls
    assert(Yikers.owns_url?('http://www.yikers.com/video_sexy_drunk_girl_crashes_dirtbike.html'))
    assert(Yikers.owns_url?('http://www.yikers.com/video_almost_transformers.html'))
    assert(Yikers.owns_url?('http://yikers.com/video_almost_transformers.html'))
    assert(Yikers.owns_url?('www.yikers.com/video_noisy_drinking_cat.html'))
    assert(Yikers.owns_url?('yikers.com/video_college_cafeteria_strip_off.html'))
  end

  
  def test_doesnt_own_howcast_urls
    assert(!Yikers.owns_url?('http://www.howcast.com/videos/6807-2twr'))
    assert(!Yikers.owns_url?('www.howcast.com/videos/6807-2dgfdg'))
    assert(!Yikers.owns_url?('http://howcast.com/videos/6807-cse'))
    assert(!Yikers.owns_url?('howcast.com/videos/6807-asdgasd'))
  end
  
    
  def test_doesnt_own_redtube_urls
    assert(!Yikers.owns_url?('http://www.redtube.com/6807'))
    assert(!Yikers.owns_url?('www.redtube.com/6807'))
    assert(!Yikers.owns_url?('http://redtube.com/6807'))
    assert(!Yikers.owns_url?('redtube.com/6807'))
  end

  def test_doesnt_own_misc_urls
    assert(!Yikers.owns_url?('http://www.howcast.com/abc'))
  end

  
  def test_parse_xml_path
    yikers = Yikers.new(nil)

    page_data = nil
    
    File.open('test/fixtures/yikers/video_college_cafeteria_strip_off.html') do |f|
      page_data = f.read
    end
    
    test_result = yikers.send('parse_xml_path', page_data)
    assert_equal('/flash/play_flash_xml.php?cid=11798', test_result)
  end


  def test_parse_video_url
    yikers = Yikers.new(nil)

    page_data = nil
    
    File.open('test/fixtures/yikers/video_college_cafeteria_strip_off.xml') do |f|
      page_data = f.read
    end
    
    test_result = yikers.send('parse_video_url', page_data)
    assert_equal('http://cdn.yikers.com/flv/flash8/yikers_college_cafeteria_strip_off.flv', test_result)
  end


  def test_get_video_filename
    yikers = Yikers.new('http://www.yikers.com/video_college_cafeteria_strip_off.html')
    assert_equal('video_college_cafeteria_strip_off.flv', yikers.get_video_filename())
  end


  def test_uri_query_works_on_yikers_urls
    uri = URI.parse('http://www.yikers.com/flash/play_flash_xml.php?cid=11798')
    http_path = uri.path + '?' + uri.query
    assert_equal('/flash/play_flash_xml.php?cid=11798', http_path)
  end
  
end
